@@ -157,6 +157,8 @@ class Saya:
         channel._export = new_channel._export
         channel._py_module = new_channel._py_module
         channel.content = new_channel.content
+
+        self.channels[channel.module] = channel
     
     def create_main_channel(self) -> Channel:
         may_current = self.channels.get("__main__")
@@ -175,5 +177,13 @@ class Saya:
             saya_instance.reset(token)
         
         return main_channel
+    
+    def find_route(self, route: str) -> Any:
+        with self.behaviour_interface.require_context(route) as interface:
+            try:
+                return interface.find_route(route)
+            except:
+                logger.exception(f"an error occurred while find a route: {route}")
+                raise
 
 from .event import SayaModuleInstalled, SayaModuleUninstall, SayaModuleUninstalled
\ No newline at end of file
